@@ -14,7 +14,7 @@ from packaging import version
 from .utils.file_utils import _LazyModule, get_tf_version, pytorch_available, tf_available
 from .utils.logger import logger
 
-__version__ = 0.21
+__version__ = 0.22
 
 _IMPORT_STRUCTURE = {
     "analyzer": ["get_dd_analyzer", "build_analyzer", "load_page", "load_document"],
@@ -183,10 +183,12 @@ _IMPORT_STRUCTURE = {
         "filter_summary",
         "image_to_cat_id",
         "remove_cats",
+        "add_summary",
         "coco_to_image",
         "image_to_coco",
         "image_to_d2_frcnn_training",
         "pt_nms_image_annotations",
+        "to_wandb_image",
         "image_to_hf_detr_training",
         "DetrDataCollator",
         "image_to_layoutlm",
@@ -301,6 +303,8 @@ _IMPORT_STRUCTURE = {
         "get_doctr_requirement",
         "fasttext_available",
         "get_fasttext_requirement",
+        "wandb_available",
+        "get_wandb_requirement",
         "load_image_from_file",
         "load_bytes_from_pdf_file",
         "get_load_image_func",
