@@ -86,7 +86,9 @@ class CacheData(ProxyDataFlow):
         self.reset_state()
         with get_tqdm() as status_bar:
             for _ in self:
-                status_bar.update()
+                status_bar.update()  # type: ignore
+            if self.shuffle:
+                self.rng.shuffle(self.buffer)
             return self.buffer
 
 
