@@ -24,7 +24,7 @@ import json
 from copy import copy
 from itertools import chain
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Sequence, Set, Type, Union, no_type_check
+from typing import Any, Dict, List, Optional, Sequence, Set, Tuple, Type, Union, no_type_check
 
 import cv2
 import numpy as np
@@ -170,6 +170,10 @@ class Layout(ImageAnnotationBaseView):
     def get_attribute_names(self) -> Set[str]:
         return {"words", "text"}.union(super().get_attribute_names()).union({Relationships.reading_order})
 
+    def __len__(self) -> int:
+        """len of text counted by number of characters"""
+        return len(self.text)
+
 
 class Cell(Layout):
     """
@@ -248,6 +252,22 @@ class Table(Layout):
     def get_attribute_names(self) -> Set[str]:
         return set(TableType).union(super().get_attribute_names()).union({"cells", "rows", "columns", "html"})
 
+    @property
+    def csv(self) -> List[List[str]]:
+        """Returns a csv-style representation of a table as list of lists of string. Cell content of cell with higher
+        row or column spans will be shown at the upper left cell tile. All other tiles covered by the cell will be left
+        as blank
+        """
+        cells = self.cells
+        table_list = [["" for _ in range(self.number_of_columns)] for _ in range(self.number_of_rows)]  # type: ignore
+        for cell in cells:
+            table_list[cell.row_number - 1][cell.column_number - 1] = cell.text  # type: ignore
+        return table_list
+
+    def __str__(self) -> str:
+        out = " ".join([" ".join(row + ["\n"]) for row in self.csv])
+        return out
+
 
 IMAGE_ANNOTATION_TO_LAYOUTS: Dict[ObjectTypes, Type[Union[Layout, Table, Word]]] = {
     **{i: Layout for i in LayoutType if (i not in {LayoutType.table, LayoutType.word, LayoutType.cell})},
@@ -272,7 +292,11 @@ def ann_obj_view_factory(annotation: ImageAnnotation, text_container: ObjectType
     :return: Transformed annotation
     """
 
-    layout_class = IMAGE_ANNOTATION_TO_LAYOUTS[annotation.category_name]
+    # We need to handle annotations that are text containers like words
+    if annotation.category_name == text_container:
+        layout_class = IMAGE_ANNOTATION_TO_LAYOUTS[LayoutType.word]
+    else:
+        layout_class = IMAGE_ANNOTATION_TO_LAYOUTS[annotation.category_name]
     ann_dict = annotation.as_dict()
     layout = layout_class.from_dict(**ann_dict)
     if image_dict := ann_dict.get("image"):
@@ -414,6 +438,8 @@ class Page(Image):
             img_kwargs.get("file_name"), img_kwargs.get("location"), img_kwargs.get("external_id")  # type: ignore
         )
         page.image_orig = image_orig
+        page.page_number = image_orig.page_number
+        page.document_id = image_orig.document_id
         if image_orig.image is not None:
             page.image = image_orig.image  # pass image explicitly so
         page._image_id = img_kwargs.get("_image_id")
@@ -465,6 +491,36 @@ class Page(Image):
             text += f"{linebreak}{getattr(block, block_attr)}"
         return text
 
+    @property
+    def chunks(self) -> List[Tuple[str, str, str, str, str, str]]:
+        """
+        :return: Returns a "chunk" of a layout element or a table as 6-tuple containing
+
+                    - document id
+                    - image id
+                    - reading order
+                    - category name
+                    - text string
+
+        """
+        block_with_order = self._order("layouts")
+        for table in self.tables:
+            if table.reading_order:
+                block_with_order.append(table)
+        all_chunks = []
+        for chunk in block_with_order:
+            all_chunks.append(
+                (
+                    self.document_id,
+                    self.image_id,
+                    chunk.annotation_id,
+                    chunk.reading_order,
+                    chunk.category_name,
+                    chunk.text,
+                )
+            )
+        return all_chunks  # type: ignore
+
     @property
     def text_no_line_break(self) -> str:
         """
@@ -512,6 +568,7 @@ class Page(Image):
 
         category_names_list: List[Union[str, None]] = []
         box_stack = []
+        cells_found = False
 
         if show_layouts:
             for item in self.layouts:
@@ -525,6 +582,7 @@ class Page(Image):
                 if show_cells:
                     for cell in table.cells:
                         if cell.category_name != LayoutType.cell:
+                            cells_found = True
                             box_stack.append(cell.bbox)
                             category_names_list.append(None)
                 if show_table_structure:
@@ -537,6 +595,12 @@ class Page(Image):
                         box_stack.append(col.bbox)
                         category_names_list.append(None)
 
+        if show_cells and not cells_found:
+            for ann in self.annotations:
+                if isinstance(ann, Cell):
+                    box_stack.append(ann.bbox)
+                    category_names_list.append(None)
+
         if show_words:
             all_words = []
             for layout in self.layouts:
