@@ -22,6 +22,7 @@ Module for the base class of datasets.
 import os
 import pprint
 from abc import ABC, abstractmethod
+from collections import defaultdict
 from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Type, Union
 
 import numpy as np
@@ -126,6 +127,41 @@ class _BuiltInDataset(DatasetBase, ABC):
         return True
 
 
+class SplitDataFlow(DataFlowBaseBuilder):
+    """
+    Dataflow builder for splitting datasets
+    """
+
+    def __init__(self, train: List[Image], val: List[Image], test: Optional[List[Image]]):
+        """
+        :param train: Cached train split
+        :param val: Cached val split
+        :param test: Cached test split
+        """
+        super().__init__(location="")
+        self.split_cache: Dict[str, List[Image]]
+        if test is None:
+            self.split_cache = {"train": train, "val": val}
+        else:
+            self.split_cache = {"train": train, "val": val, "test": test}
+
+    def build(self, **kwargs: Union[str, int]) -> DataFlow:
+        """
+        Dataflow builder for merged split datasets
+        :param kwargs: Only split and max_datapoints arguments will be considered.
+        :return: Dataflow
+        """
+
+        split = kwargs.get("split", "train")
+        if not isinstance(split, str):
+            raise ValueError("'split' must be a string")
+        max_datapoints = kwargs.get("max_datapoints")
+        if isinstance(max_datapoints, str):
+            max_datapoints = int(max_datapoints)
+
+        return CustomDataFromList(self.split_cache[split], max_datapoints=max_datapoints)
+
+
 class MergeDataset(DatasetBase):
     """
     A class for merging dataset ready to feed a training or an evaluation script. The dataflow builder will generate
@@ -177,6 +213,7 @@ class MergeDataset(DatasetBase):
         self.datapoint_list: Optional[List[Image]] = None
         super().__init__()
         self._dataset_info.type = datasets[0].dataset_info.type
+        self._dataset_info.name = "merge_" + "_".join([dataset.dataset_info.name for dataset in self.datasets])
 
     def _categories(self) -> DatasetCategories:
         return get_merged_categories(
@@ -281,41 +318,55 @@ class MergeDataset(DatasetBase):
             )
         )
 
-        class SplitDataFlow(DataFlowBaseBuilder):
-            """
-            Dataflow builder for splitting datasets
-            """
+        self._dataflow_builder = SplitDataFlow(train_dataset, val_dataset, test_dataset)
+        self._dataflow_builder.categories = self._categories()
 
-            def __init__(self, train: List[Image], val: List[Image], test: Optional[List[Image]]):
-                """
-                :param train: Cached train split
-                :param val: Cached val split
-                :param test: Cached test split
-                """
-                super().__init__(location="")
-                self.split_cache: Dict[str, List[Image]]
-                if test is None:
-                    self.split_cache = {"train": train, "val": val}
-                else:
-                    self.split_cache = {"train": train, "val": val, "test": test}
+    def get_ids_by_split(self) -> Dict[str, List[str]]:
+        """
+        To reproduce a dataset split at a later stage, get a summary of the by having a dict of list with split and
+        the image ids contained in the split.
 
-            def build(self, **kwargs: Union[str, int]) -> DataFlow:
-                """
-                Dataflow builder for merged split datasets.
+        :return: E.g. `{"train": ['ab','ac'],"val":['bc','bd']}`
+        """
+        if isinstance(self._dataflow_builder, SplitDataFlow):
+            return {
+                key: [img.image_id for img in self._dataflow_builder.split_cache.get(key, [])]
+                for key in ("train", "val", "test")
+            }
+        return {"train": [], "val": [], "test": []}
 
-                :param kwargs: Only split and max_datapoints arguments will be considered.
-                :return: Dataflow
-                """
+    def create_split_by_id(
+        self, split_dict: Mapping[str, Sequence[str]], **dataflow_build_kwargs: Union[str, int]
+    ) -> None:
+        """
+        Reproducing a dataset split from a dataset or a dataflow by a dict of list of image ids.
 
-                split = kwargs.get("split", "train")
-                if not isinstance(split, str):
-                    raise ValueError("'split' must be a string")
-                max_datapoints = kwargs.get("max_datapoints")
-                if isinstance(max_datapoints, str):
-                    max_datapoints = int(max_datapoints)
+            merge = dd.MergeDataset(doclaynet)
+            merge.explicit_dataflows(df_doc)
+            merge.buffer_datasets()
+            merge.split_datasets(ratio=0.1)
+            out = merge.get_ids_by_split()   # Save out somewhere
 
-                return CustomDataFromList(self.split_cache[split], max_datapoints=max_datapoints)
+            merge_2 = dd.MergeDataset(doclaynet)
+            df_doc_2 = doclaynet.dataflow.build(split="train", max_datapoints=4000)
+            merge_2.explicit_dataflows(df_doc_2)
+            merge_2.create_split_by_id(out)   # merge_2 now has the same split as merge
 
+        :param split_dict: e.g. `{"train":['ab','ac',...],"val":['bc'],"test":[]}`
+        """
+
+        if set(split_dict.keys()) != {"train", "val", "test"}:
+            raise KeyError("split_dict must contain keys for 'train', 'val' and 'test'")
+        ann_id_to_split = {ann_id: "train" for ann_id in split_dict["train"]}
+        ann_id_to_split.update({ann_id: "val" for ann_id in split_dict["val"]})
+        ann_id_to_split.update({ann_id: "test" for ann_id in split_dict["test"]})
+        self.buffer_datasets(**dataflow_build_kwargs)
+        split_defaultdict = defaultdict(list)
+        for image in self.datapoint_list:  # type: ignore
+            split_defaultdict[ann_id_to_split[image.image_id]].append(image)
+        train_dataset = split_defaultdict["train"]
+        val_dataset = split_defaultdict["val"]
+        test_dataset = split_defaultdict["test"]
         self._dataflow_builder = SplitDataFlow(train_dataset, val_dataset, test_dataset)
         self._dataflow_builder.categories = self._categories()
 
