@@ -83,18 +83,21 @@ _SUB_CATEGORIES = {
         CellType.column_number: [],
         CellType.row_span: [],
         CellType.column_span: [],
+        CellType.spanning: [CellType.spanning],
     },
     CellType.header: {
         CellType.row_number: [],
         CellType.column_number: [],
         CellType.row_span: [],
         CellType.column_span: [],
+        CellType.spanning: [CellType.spanning],
     },
     CellType.body: {
         CellType.row_number: [],
         CellType.column_number: [],
         CellType.row_span: [],
         CellType.column_span: [],
+        CellType.spanning: [CellType.spanning],
     },
     LayoutType.table: {TableType.html: [TableType.html]},
     LayoutType.word: {WordType.characters: [WordType.characters]},
@@ -179,6 +182,7 @@ class PubtabnetBuilder(DataFlowBaseBuilder):
             rows_and_cols=rows_and_cols,
             dd_pipe_like=dd_pipe_like,
             is_fintabnet=False,
+            pubtables_like=False,
         )
 
         df = MapData(df, pub_mapper)
