@@ -291,15 +291,13 @@ class HFLayoutLmTokenClassifierBase(LMTokenClassifier, ABC):
 
 class HFLayoutLmTokenClassifier(HFLayoutLmTokenClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMForTokenClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/model_doc/layoutlm for documentation of the model itself.
+    A wrapper class for `transformers.LayoutLMForTokenClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/model_doc/layoutlm> for documentation of the model itself.
     Note that this model is equipped with a head that is only useful when classifying tokens. For sequence
     classification and other things please use another model of the family.
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
@@ -355,11 +353,15 @@ class HFLayoutLmTokenClassifier(HFLayoutLmTokenClassifierBase):
         """
         Launch inference on LayoutLm for token classification. Pass the following arguments
 
-        :param input_ids: Token converted to ids to be taken from LayoutLMTokenizer
-        :param attention_mask: The associated attention masks from padded sequences taken from LayoutLMTokenizer
-        :param token_type_ids: Torch tensor of token type ids taken from LayoutLMTokenizer
-        :param boxes: Torch tensor of bounding boxes of type 'xyxy'
-        :param tokens: List of original tokens taken from LayoutLMTokenizer
+        `input_ids:` Token converted to ids to be taken from `LayoutLMTokenizer`
+
+        `attention_mask:` The associated attention masks from padded sequences taken from `LayoutLMTokenizer`
+
+        `token_type_ids:` Torch tensor of token type ids taken from `LayoutLMTokenizer`
+
+        `boxes:` Torch tensor of bounding boxes of type 'xyxy'
+
+        `tokens:` List of original tokens taken from `LayoutLMTokenizer`
 
         :return: A list of TokenClassResults
         """
@@ -375,8 +377,8 @@ class HFLayoutLmTokenClassifier(HFLayoutLmTokenClassifierBase):
 
 class HFLayoutLmv2TokenClassifier(HFLayoutLmTokenClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMv2ForTokenClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv2  for documentation of the model
+    A wrapper class for `transformers.LayoutLMv2ForTokenClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv2>  for documentation of the model
     itself. Note that this model is equipped with a head that is only useful when classifying tokens. For sequence
     classification and other things please use another model of the family.
 
@@ -384,8 +386,6 @@ class HFLayoutLmv2TokenClassifier(HFLayoutLmTokenClassifierBase):
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
@@ -441,11 +441,15 @@ class HFLayoutLmv2TokenClassifier(HFLayoutLmTokenClassifierBase):
         """
         Launch inference on LayoutLm for token classification. Pass the following arguments
 
-        :param input_ids: Token converted to ids to be taken from LayoutLMTokenizer
-        :param attention_mask: The associated attention masks from padded sequences taken from LayoutLMTokenizer
-        :param token_type_ids: Torch tensor of token type ids taken from LayoutLMTokenizer
-        :param boxes: Torch tensor of bounding boxes of type 'xyxy'
-        :param tokens: List of original tokens taken from LayoutLMTokenizer
+        `input_ids:` Token converted to ids to be taken from `LayoutLMTokenizer`
+
+        `attention_mask:` The associated attention masks from padded sequences taken from `LayoutLMTokenizer`
+
+        `token_type_ids:` Torch tensor of token type ids taken from `LayoutLMTokenizer`
+
+        `boxes:` Torch tensor of bounding boxes of type `xyxy`
+
+        `tokens:` List of original tokens taken from `LayoutLMTokenizer`
 
         :return: A list of TokenClassResults
         """
@@ -474,8 +478,8 @@ class HFLayoutLmv2TokenClassifier(HFLayoutLmTokenClassifierBase):
 
 class HFLayoutLmv3TokenClassifier(HFLayoutLmTokenClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMv3ForTokenClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv3  for documentation of the model
+    A wrapper class for `transformers.LayoutLMv3ForTokenClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv3>  for documentation of the model
     itself. Note that this model is equipped with a head that is only useful when classifying tokens. For sequence
     classification and other things please use another model of the family.
 
@@ -483,8 +487,6 @@ class HFLayoutLmv3TokenClassifier(HFLayoutLmTokenClassifierBase):
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
@@ -540,11 +542,11 @@ class HFLayoutLmv3TokenClassifier(HFLayoutLmTokenClassifierBase):
         """
         Launch inference on LayoutLm for token classification. Pass the following arguments
 
-        :param input_ids: Token converted to ids to be taken from LayoutLMTokenizer
-        :param attention_mask: The associated attention masks from padded sequences taken from LayoutLMTokenizer
-        :param token_type_ids: Torch tensor of token type ids taken from LayoutLMTokenizer
-        :param boxes: Torch tensor of bounding boxes of type 'xyxy'
-        :param tokens: List of original tokens taken from LayoutLMTokenizer
+        `input_ids:` Token converted to ids to be taken from `LayoutLMTokenizer`
+        `attention_mask:` The associated attention masks from padded sequences taken from `LayoutLMTokenizer`
+        `token_type_ids:` Torch tensor of token type ids taken from `LayoutLMTokenizer`
+        `boxes:` Torch tensor of bounding boxes of type 'xyxy'
+        `tokens:` List of original tokens taken from `LayoutLMTokenizer`
 
         :return: A list of TokenClassResults
         """
@@ -680,15 +682,13 @@ class HFLayoutLmSequenceClassifierBase(LMSequenceClassifier, ABC):
 
 class HFLayoutLmSequenceClassifier(HFLayoutLmSequenceClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMForSequenceClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/model_doc/layoutlm for documentation of the model itself.
+    A wrapper class for `transformers.LayoutLMForSequenceClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/model_doc/layoutlm> for documentation of the model itself.
     Note that this model is equipped with a head that is only useful for classifying the input sequence. For token
     classification and other things please use another model of the family.
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
@@ -743,15 +743,13 @@ class HFLayoutLmSequenceClassifier(HFLayoutLmSequenceClassifierBase):
 
 class HFLayoutLmv2SequenceClassifier(HFLayoutLmSequenceClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMv2ForSequenceClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv2 for documentation of the model
+    A wrapper class for `transformers.LayoutLMv2ForSequenceClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv2> for documentation of the model
     itself. Note that this model is equipped with a head that is only useful for classifying the input sequence. For
     token classification and other things please use another model of the family.
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
@@ -813,15 +811,13 @@ class HFLayoutLmv2SequenceClassifier(HFLayoutLmSequenceClassifierBase):
 
 class HFLayoutLmv3SequenceClassifier(HFLayoutLmSequenceClassifierBase):
     """
-    A wrapper class for :class:`transformers.LayoutLMv3ForSequenceClassification` to use within a pipeline component.
-    Check https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv3 for documentation of the model
+    A wrapper class for `transformers.LayoutLMv3ForSequenceClassification` to use within a pipeline component.
+    Check <https://huggingface.co/docs/transformers/v4.24.0/en/model_doc/layoutlmv3> for documentation of the model
     itself. Note that this model is equipped with a head that is only useful for classifying the input sequence. For
     token classification and other things please use another model of the family.
 
     **Example**
 
-        .. code-block:: python
-
             # setting up compulsory ocr service
             tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
             tess = TesseractOcrDetector(tesseract_config_path)
