@@ -16,8 +16,7 @@
 # limitations under the License.
 
 """
-Init file for mapper package. Contains everything that is related to transformation between datapoints
-
+Contains everything that is related to transformation between datapoints
 """
 from typing import Callable, Optional
 
@@ -34,10 +33,11 @@ from .pubstruct import *
 from .tpstruct import *
 from .xfundstruct import *
 
-if detectron2_available():
+if detectron2_available() and pytorch_available():
     from .d2struct import *
 
 if pytorch_available() and transformers_available():
+    from .hfstruct import *
     from .laylmstruct import *
 
 
