@@ -42,7 +42,7 @@ def test_cat_to_sub_cat(datapoint_pubtabnet: JsonDict, pubtabnet_results: Datapo
     """
     # Arrange
     categories_name_as_key_init = {LayoutType.cell: "1", TableType.item: "2"}
-    pub_to_image_mapper = pub_to_image(categories_name_as_key_init, False, False, True, False, False)
+    pub_to_image_mapper = pub_to_image(categories_name_as_key_init, False, False, True, False, False, False)
     dp = pub_to_image_mapper(datapoint_pubtabnet)
 
     categories = MagicMock()
@@ -85,7 +85,7 @@ def test_filter_categories(datapoint_pubtabnet: JsonDict, pubtabnet_results: Dat
 
     # Arrange
     categories_name_as_key_init = {LayoutType.cell: "1", TableType.item: "2"}
-    pub_to_image_mapper = pub_to_image(categories_name_as_key_init, False, False, True, False, False)
+    pub_to_image_mapper = pub_to_image(categories_name_as_key_init, False, False, True, False, False, False)
     dp = pub_to_image_mapper(datapoint_pubtabnet)
     assert dp is not None
 
