@@ -50,7 +50,7 @@ def test_image_to_d2_frcnn_training(datapoint_image: Image, image_results: Datap
     assert output["width"] == output["width"]
 
     first_annotation = output["annotations"][0]
-    expected_first_annotation = output["annotations"][0]
+    expected_first_annotation = expected_output["annotations"][0]
 
     assert first_annotation["bbox"] == expected_first_annotation["bbox"]
     assert first_annotation["category_id"] == expected_first_annotation["category_id"]
