@@ -25,7 +25,6 @@ from typing import Any, Iterable, Iterator, List, Optional, Union
 
 from deepdoctection.dataflow import DataFlow
 from deepdoctection.datapoint import Annotation
-from deepdoctection.utils.systools import get_package_path
 
 
 def get_test_path() -> Path:
@@ -39,7 +38,7 @@ def get_integration_test_path() -> Path:
     """
     fixture integration test path
     """
-    return get_package_path() / "notebooks" / "pics" / "samples" / "sample_2"
+    return get_test_path() / "sample_2"
 
 
 def collect_datapoint_from_dataflow(
